==> actions_lib-0.1.110.tar.gz: actions_lib-0.1.110/actions_lib/actions/consts.py <==
# Constants
TOKEN_MAPPING = {
    "ethereum": {
        "eth": {
            "address": None,
            "decimal": 18
        },
        # testnet
        "usdc": {
            "address": "0xd10519Aa03FE7Ffb95189B52B74F94Fb33E2C88a",
            "decimal": 6
        },
        # mainnet
        # "usdc": {
        #     "address": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
        #     "decimal": 6
        # },
        "usdt": {
            "address": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "decimal": 6
        },
        "bnb": {
            "address": "0xB8c77482e45F1F44dE1745F52C74426C631bDD52",
            "decimal": 18
        },
        "dai": {
            "address": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "decimal": 18
        },
        "uni": {
            "address": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "decimal": 18
        },
        "btc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "wbtc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "cbbtc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "ens": {
            "address": "0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72",
            "decimal": 18
        }
    },
    "eth": {
        "eth": {
            "address": None,
            "decimal": 18
        },
        # testnet
        "usdc": {
            "address": "0xd10519Aa03FE7Ffb95189B52B74F94Fb33E2C88a",
            "decimal": 6
        },
        # mainnet
        # "usdc": {
        #     "address": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
        #     "decimal": 6
        # },
        "usdt": {
            "address": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "decimal": 6
        },
        "bnb": {
            "address": "0xB8c77482e45F1F44dE1745F52C74426C631bDD52",
            "decimal": 18
        },
        "dai": {
            "address": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "decimal": 18
        },
        "uni": {
            "address": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "decimal": 18
        },
        "btc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "wbtc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "cbbtc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "ens": {
            "address": "0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72",
            "decimal": 18
        }
    },
    "base": {
        "eth": {
            "address": None,
            "decimal": 18
        },
        # testnet
        "usdc": {
            "address": "0x45b58118a5374dccf7fd6f3f66c66278ab7473d9",
            "decimal": 6
        },
        # mainnet
        # "usdc": {
        #     "address": "0x833589fCD6eDb6E08f4c7C32D4f71b54bdA02913",
        #     "decimal": 6
        # },
        "btc": {
            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
            "decimal": 8
        },
        "wbtc": {
            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
            "decimal": 8
        },
        "cbbtc": {
            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
            "decimal": 8
        }
    },
}

#sepolia
CHAIN_ID_MAPPING = {
    'base': 84532,
    'ethereum': 11155111,
    'eth': 11155111
}

# mainnet
# CHAIN_ID_MAPPING = {
#     'base': 8453,
#     'ethereum': 1,
#     'eth': 1
# }

==> actions_lib-0.1.123.tar.gz: actions_lib-0.1.123/actions_lib/actions/consts.py <==
# Constants
TOKEN_MAPPING = {
    "ethereum": {
        "eth": {
            "address": None,
            "decimal": 18
        },
        # testnet
        # "usdc": {
        #     "address": "0xd10519Aa03FE7Ffb95189B52B74F94Fb33E2C88a",
        #     "decimal": 6
        # },
        # mainnet
        "usdc": {
            "address": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "decimal": 6
        },
        "usdt": {
            "address": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "decimal": 6
        },
        "bnb": {
            "address": "0xB8c77482e45F1F44dE1745F52C74426C631bDD52",
            "decimal": 18
        },
        "dai": {
            "address": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "decimal": 18
        },
        "uni": {
            "address": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "decimal": 18
        },
        "btc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "wbtc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "cbbtc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "ens": {
            "address": "0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72",
            "decimal": 18
        }
    },
    "eth": {
        "eth": {
            "address": None,
            "decimal": 18
        },
        # testnet
        # "usdc": {
        #     "address": "0xd10519Aa03FE7Ffb95189B52B74F94Fb33E2C88a",
        #     "decimal": 6
        # },
        # mainnet
        "usdc": {
            "address": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
            "decimal": 6
        },
        "usdt": {
            "address": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
            "decimal": 6
        },
        "bnb": {
            "address": "0xB8c77482e45F1F44dE1745F52C74426C631bDD52",
            "decimal": 18
        },
        "dai": {
            "address": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
            "decimal": 18
        },
        "uni": {
            "address": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
            "decimal": 18
        },
        "btc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "wbtc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "cbbtc": {
            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
            "decimal": 8
        },
        "ens": {
            "address": "0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72",
            "decimal": 18
        }
    },
    "base": {
        "eth": {
            "address": None,
            "decimal": 18
        },
        # testnet
        # "usdc": {
        #     "address": "0x45b58118a5374dccf7fd6f3f66c66278ab7473d9",
        #     "decimal": 6
        # },
        # mainnet
        "usdc": {
            "address": "0x833589fCD6eDb6E08f4c7C32D4f71b54bdA02913",
            "decimal": 6
        },
        "btc": {
            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
            "decimal": 8
        },
        "wbtc": {
            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
            "decimal": 8
        },
        "cbbtc": {
            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
            "decimal": 8
        }
    },
}

#sepolia
# CHAIN_ID_MAPPING = {
#     'base': 84532,
#     'ethereum': 11155111,
#     'eth': 11155111
# }

# mainnet
CHAIN_ID_MAPPING = {
    'base': 8453,
    'ethereum': 1,
    'eth': 1
}
